cgexplore.optimisation.CGOMMDynamics
====================================

.. currentmodule:: cgexplore.optimisation

.. autoclass:: CGOMMDynamics
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CGOMMDynamics.run_dynamics
   
   

   
   
   